==> zc.async-1.1.1.tar.gz: zc.async-1.1.1/src/zc/async/z3tests.py <==
##############################################################################
#
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os
import unittest
from zope.testing import doctest, module
import zope.component.testing
import zc.ngi.async # to quiet the thread complaints from the testing
# infrastructure, because there is no API way to stop the z3monitor server or
# the zc.ngi.async thread. :-(

import zc.async.tests

def setUp(test):
    zc.async.tests.modSetUp(test)
    # make the uuid stable for these tests
    f = open(os.environ["ZC_ASYNC_UUID"], 'w')
    # make this stable for test purposes
    f.writelines(('d10f43dc-ffdf-11dc-abd4-0017f2c49bdd',))
    f.close()
    zc.async.instanceuuid.UUID = zc.async.instanceuuid.getUUID()

def tearDown(test):
    import zc.async.dispatcher
    zc.async.dispatcher.pop()
    zope.component.testing.tearDown(test)

def test_suite():
    return unittest.TestSuite((
        doctest.DocFileSuite(
            'monitor.txt',
            setUp=setUp, tearDown=zc.async.tests.modTearDown,
            optionflags=doctest.INTERPRET_FOOTNOTES),
        doctest.DocFileSuite(
            'README_3.txt',
            'README_3b.txt',
            setUp=zope.component.testing.setUp,
            tearDown=tearDown,
            optionflags=doctest.INTERPRET_FOOTNOTES),
        ))


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')

==> zc.async-1.4.1.tar.gz: zc.async-1.4.1/src/zc/async/z3tests.py <==
##############################################################################
#
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os
import unittest
from zope.testing import doctest, module
import zope.component.testing
import zc.ngi.async # to quiet the thread complaints from the testing
# infrastructure, because there is no API way as of this writing to stop the
# z3monitor server or the zc.ngi.async thread. :-(

import zc.async.tests

def setUp(test):
    zc.async.tests.modSetUp(test)
    # make the uuid stable for these tests
    f = open(os.environ["ZC_ASYNC_UUID"], 'w')
    # make this stable for test purposes
    f.writelines(('d10f43dc-ffdf-11dc-abd4-0017f2c49bdd',))
    f.close()
    zc.async.instanceuuid.UUID = zc.async.instanceuuid.getUUID()

def tearDown(test):
    import zc.async.dispatcher
    zc.async.dispatcher.pop()
    zope.component.testing.tearDown(test)

def test_suite():
    return unittest.TestSuite((
        doctest.DocFileSuite(
            'monitor.txt',
            'z3.txt',
            setUp=setUp, tearDown=zc.async.tests.modTearDown,
            optionflags=doctest.INTERPRET_FOOTNOTES),
        doctest.DocFileSuite(
            'README_3.txt',
            'README_3b.txt',
            setUp=zope.component.testing.setUp,
            tearDown=tearDown,
            optionflags=doctest.INTERPRET_FOOTNOTES),
        ))


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
